==> haskell-securemem-0.1.9-28-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-securemem.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: securemem
version: 0.1.9
id: securemem-0.1.9-KrborjLaUmaBa3n2Ut05aK
key: securemem-0.1.9-KrborjLaUmaBa3n2Ut05aK
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-securemem
synopsis: abstraction to an auto scrubbing and const time eq, memory chunk.
description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.SecureMem
abi: bafd9851fe7e417e3885a49e80d7e0a4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/securemem-0.1.9
library-dirs: /usr/lib/ghc-8.2.2/site-local/securemem-0.1.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/securemem-0.1.9
hs-libraries: HSsecuremem-0.1.9-KrborjLaUmaBa3n2Ut05aK
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
    memory-0.14.10-LwCYa6TFutlHfUbiGZd8KU ghc-prim-0.5.1.1
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=d7caed3dfdc2cc9400ff9a46cbe7296d
             memory-0.14.10-LwCYa6TFutlHfUbiGZd8KU=ab92cc9732ca92f3c7dffc63e7dfa885
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
haddock-interfaces: /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html: /usr/share/doc/haskell-securemem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-securemem-0.1.9-31-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-securemem.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: securemem
version: 0.1.9
id: securemem-0.1.9-84q5RqtbDCk6EVPVYkeBse
key: securemem-0.1.9-84q5RqtbDCk6EVPVYkeBse
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-securemem
synopsis: abstraction to an auto scrubbing and const time eq, memory chunk.
description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.SecureMem
abi: a44a2b07a0fc59da1abd4f27c0bace0a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/securemem-0.1.9
library-dirs: /usr/lib/ghc-8.2.2/site-local/securemem-0.1.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/securemem-0.1.9
hs-libraries: HSsecuremem-0.1.9-84q5RqtbDCk6EVPVYkeBse
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
    memory-0.14.12-BTp4cbdvYCLFqY2CwtLFIt ghc-prim-0.5.1.1
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=d7caed3dfdc2cc9400ff9a46cbe7296d
             memory-0.14.12-BTp4cbdvYCLFqY2CwtLFIt=0bbf4eba75d66590f8174b4addb225f6
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
haddock-interfaces: /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html: /usr/share/doc/haskell-securemem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
